
#ifndef VTKRENDERINGOPENVR_EXPORT_H
#define VTKRENDERINGOPENVR_EXPORT_H

#ifdef VTKRENDERINGOPENVR_STATIC_DEFINE
#  define VTKRENDERINGOPENVR_EXPORT
#  define VTKRENDERINGOPENVR_NO_EXPORT
#else
#  ifndef VTKRENDERINGOPENVR_EXPORT
#    ifdef RenderingOpenVR_EXPORTS
        /* We are building this library */
#      define VTKRENDERINGOPENVR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKRENDERINGOPENVR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKRENDERINGOPENVR_NO_EXPORT
#    define VTKRENDERINGOPENVR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKRENDERINGOPENVR_DEPRECATED
#  define VTKRENDERINGOPENVR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKRENDERINGOPENVR_DEPRECATED_EXPORT
#  define VTKRENDERINGOPENVR_DEPRECATED_EXPORT VTKRENDERINGOPENVR_EXPORT VTKRENDERINGOPENVR_DEPRECATED
#endif

#ifndef VTKRENDERINGOPENVR_DEPRECATED_NO_EXPORT
#  define VTKRENDERINGOPENVR_DEPRECATED_NO_EXPORT VTKRENDERINGOPENVR_NO_EXPORT VTKRENDERINGOPENVR_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKRENDERINGOPENVR_NO_DEPRECATED
#    define VTKRENDERINGOPENVR_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkRenderingOpenVRModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKRENDERINGOPENVR_EXPORT_H */
